
# Type: treated by


holds between a disease or phenotypic feature and a therapeutic process or chemical substance that is used to treat the condition

URI: [biolink:treated_by](https://w3id.org/biolink/vocab/treated_by)


## Domain and Range

[DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md) ->  <sub>0..*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [PhenotypicFeature](PhenotypicFeature.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002302 |
|  | | WD:P2176 |
| **In Subsets:** | | translator_minimal |

